@@ -11,7 +11,7 @@ function (x, data=NULL, ..., subset, na.action = na.omit){
   m$... <- NULL
   m$formula <- m$x
   m$x <- NULL
-  m[[1]] <- as.name("model.frame")
+  m[[1L]] <- quote(stats::model.frame)  
   m <- eval(m, parent.frame())
   Terms <- attr(m, "terms")
   attr(Terms, "intercept") <- 0
