@@ -42,7 +42,7 @@
 #include <vector>
 #include <stack>
 #include <queue>
-#include <algorithm> 
+#include <algorithm>
 #include <cassert>
 #include <numeric>
 #include <fstream>
@@ -55,9 +55,9 @@
 extern "C"
 {
 #endif
-	
+
 #include "sarray.h"
-	
+
 #ifdef __cplusplus
 }
 #endif
@@ -75,10 +75,10 @@ extern "C"
 #define MIN(x,y) (((x) < (y)) ? (x):(y))
 
 
-ESA::ESA(const UInt32 & size_, SYMBOL *text_, int verb): 
+ESA::ESA(const UInt32 & size_, SYMBOL *text_, int verb):
   _verb(verb),
-  size(size_), 
-  text(text_), 
+  size(size_),
+  text(text_),
   suftab(0),
   lcptab(size_),
   childtab(size_, lcptab),
@@ -90,7 +90,7 @@ ESA::ESA(const UInt32 & size_, SYMBOL *text_, int verb):
 	coef4(0),
 	bcktab_key8(0),
 	coef8(0)
-{  
+{
 
   I_SAFactory* sa_fac = 0;
   I_LCPFactory* lcp_fac = 0;
@@ -98,25 +98,25 @@ ESA::ESA(const UInt32 & size_, SYMBOL *text_, int verb):
 	//' input validation
 	assert(size > 0);
 
-	
+
 	//	if(text[size-1] != SENTINEL)
 	//   text = (SYMBOL*)(std::string(text)+SENTINEL).c_str();
-	
+
 	assert(text[size-1] == SENTINEL);
-	  
+
 	//  CW Sanity test
-	for (int i = 0; i < size-1 ; i++) {
+	for (unsigned int i = 0; i < size-1 ; i++) {
 		assert(text[i] != 0);
 	}
 
 	//	for (int i = 0; i < size ; i++) {
 	  //		printf("%c : %i\n", text[i], (int) text[i]);
-	//	}	
-	
+	//	}
+
 
 #if SSARRAY
 	suftab = new int[size];
-    for (int i = 0; i < size - 1 ; i++) {
+    for (unsigned int i = 0; i < size - 1 ; i++) {
 		suftab[i] = text[i];
 	}
 	suftab[size-1] = 0;
@@ -126,7 +126,7 @@ ESA::ESA(const UInt32 & size_, SYMBOL *text_, int verb):
 	if(!sa_fac){
 		sa_fac = new W_msufsort();
 	}
-	
+
 	// CW Try
 	//	size = 10;
 	//	text[size-1] = 0;
@@ -135,9 +135,9 @@ ESA::ESA(const UInt32 & size_, SYMBOL *text_, int verb):
 	sa_fac->ConstructSA(text, size, suftab);
 	if(sa_fac) { delete sa_fac; sa_fac = NULL; }
 #endif
-	
 
-	
+
+
 	//' Compute LCP array
 	if(!lcp_fac){
 		lcp_fac = new W_kasai_lcp();
@@ -165,19 +165,19 @@ ESA::ESA(const UInt32 & size_, SYMBOL *text_, int verb):
 	suflink = new UInt32[2 * size + 2];  //' extra space for extra sentinel char!
 	memset(suflink,0,sizeof(UInt32)*(2 * size +2));
 	ConstructSuflink();
-	
+
 
 #else
 
 	//' Threshold for constructing bucket table
-	if(size >= 1024) 
+	if(size >= 1024)
 		ConstructBcktab();
 
-  
+
 	//' Otherwise, just do plain binary search to search for suffix link interval
-	
+
 #endif
-	
+
 }
 
 
@@ -195,14 +195,14 @@ ESA::~ESA()
 
 /// The lcp-interval structure. Used in ESA::ConstructChildTable()
 class lcp_interval {
-	
+
 public:
 
 	UInt32 lcp;
 	UInt32 lb;
 	UInt32 rb;
   std::vector<lcp_interval *> child;
-  
+
 	/// Constructors
 	lcp_interval(){}
 
@@ -211,7 +211,7 @@ public:
 		lcp = lcp_;
 		lb = lb_;
 		rb = rb_;
-    if(itv) 
+    if(itv)
       child.push_back(itv);
 	}
 
@@ -221,7 +221,7 @@ public:
 			delete child[i];
 		child.clear();
 	}
-  
+
 };
 
 
@@ -230,45 +230,45 @@ public:
  */
 ErrorCode
 ESA::ConstructChildTable(){
-	
+
 	// Input validation
 	assert(text);
 	assert(suftab);
 
-	
+
 	//' stack for lcp-intervals
   std::stack<lcp_interval*> lit;
 
-	
+
 	//' Refer to: Abo05::Algorithm 4.5.2.
 	lcp_interval *lastInterval = 0;
 	lcp_interval *new_itv = 0;
 	lit.push(new lcp_interval(0, 0, 0, 0));  //' root interval
 
 
-  // Variables to handle 0-idx 
+  // Variables to handle 0-idx
   bool first = true;
   UInt32 prev_0idx = 0;
   UInt32 first0idx = 0;
-	  
-	// Loop thru and process each index. 
+
+	// Loop thru and process each index.
 	for(UInt32 idx = 1; idx < size + 1; idx++) {
-    
+
 		UInt32 tmp_lb = idx - 1;
 
 		//svnvish: BUGBUG
-    // We just assume that the lcp of size + 1 is zero. 
+    // We just assume that the lcp of size + 1 is zero.
     // This simplifies the logic of the code
     UInt32 lcp_idx = 0;
     if(idx < size){
 			lcp_idx = lcptab[idx];
-    } 
-    
+    }
+
 		while (lcp_idx < lit.top()->lcp){
-      
+
       lastInterval = lit.top(); lit.pop();
 			lastInterval->rb = idx - 1;
-            
+
       // svnvish: Begin process
 			UInt32 n_child = lastInterval->child.size();
 			UInt32 i = lastInterval->lb;
@@ -279,47 +279,47 @@ ESA::ConstructChildTable(){
 			UInt32 first_l_index = i+1;
       if(n_child && (lastInterval->child[0]->lb == i))
         first_l_index = lastInterval->child[0]->rb+1;
-      
+
 
       //svnvish: BUGBUG
       // ec = childtab.Set_Up(lastInterval->rb+1, first_l_index);
       // ec = childtab.Set_Down(lastInterval->lb, first_l_index);
-      
-      childtab[lastInterval->rb] = first_l_index; 
+
+      childtab[lastInterval->rb] = first_l_index;
       childtab[lastInterval->lb] = first_l_index;
 
       // Now we need to set the NextlIndex fields The main problem here
       // is that the child intervals might not be contiguous
-      
+
       UInt32 ptr = i+1;
       UInt32 child_count = 0;
-      
+
       while(ptr < j){
         UInt32 first = j;
         UInt32 last = j;
-        
+
         // Get next child to process
         if(n_child - child_count){
           first = lastInterval->child[child_count]->lb;
           last = lastInterval->child[child_count]->rb;
           child_count++;
         }
-        
+
         // Eat away singleton intervals
         while(ptr < first){
 					childtab[ptr] = ptr + 1;
           ptr++;
         }
-      
+
         // Handle an child interval and make appropriate entries in
         // child table
         ptr = last + 1;
 				if(last < j){
 					childtab[first] = ptr;
         }
-				
+
       }
-      
+
 
 			//' Free lcp_intervals
 			for(UInt32 child_cnt = 0; child_cnt < n_child; child_cnt++) {
@@ -332,19 +332,19 @@ ESA::ConstructChildTable(){
 
 			if(lcp_idx <= lit.top()->lcp) {
 				lit.top()->child.push_back(lastInterval);
-        lastInterval = 0; 
+        lastInterval = 0;
 			}
-      
+
 		}// while
-    
-    
+
+
 		if(lcp_idx > lit.top()->lcp) {
 			new_itv = new lcp_interval(lcp_idx, tmp_lb,0, lastInterval);
 		  lit.push(new_itv);
 			new_itv = 0;
 			lastInterval = 0;
 		}
-    
+
     // Handle the 0-indices.
     // 0-indices := { i | LCP[i]=0, \forall i = 0,...,n-1}
     if((idx < size) && (lcp_idx == 0)) {
@@ -399,7 +399,7 @@ ESA::GetSuflink(const UInt32 &i, const UInt32 &j,	UInt32 &sl_i, UInt32 &sl_j)
 
 	//' Step 1: Get first l-index
 	childtab.l_idx(i,j,idx);
-	
+
 
 	//' Step 2: Get suffix link interval
 	sl_i = suflink[idx+idx];
@@ -419,7 +419,7 @@ ESA::GetSuflink(const UInt32 &i, const UInt32 &j,	UInt32 &sl_i, UInt32 &sl_j)
  *
  *  Note: Slow!!! especially in the case of long and similar texts.
  */
-ErrorCode 
+ErrorCode
 ESA::GetSuflink(const UInt32 &i, const UInt32 &j,
 									UInt32 &sl_i, UInt32 &sl_j)
 {
@@ -428,17 +428,17 @@ ESA::GetSuflink(const UInt32 &i, const UInt32 &j,
 	UInt32 lcp=0;
 	UInt32 final_lcp = 0;
 	UInt32 lb = 0, rb = size-1;  //' root interval
-	
+
 	//' First suflink interval char := Second char of original interval
 	ch = text[suftab[i]+1];
-	
-	
+
+
 	//' lcp of suffix link interval := lcp of original interval - 1
 	final_lcp = 0;
 	GetLcp(i,j,final_lcp);
 	final_lcp = (final_lcp > 0) ? final_lcp-1 : 0;
 
-	
+
 	//' Searching for suffix link interval
 	sl_i = lb;
 	sl_j = rb;
@@ -451,10 +451,10 @@ ESA::GetSuflink(const UInt32 &i, const UInt32 &j,
 		rb = sl_j;
 		ch = text[suftab[i]+lcp+1];
 	}
-	
+
 	assert(sl_j > sl_i);
 	assert((sl_j-sl_i) >= (j-i));
-	
+
 	return NOERROR;
 }
 
@@ -473,33 +473,33 @@ ESA::ConstructBcktab(const UInt32 &alphabet_size)
 	UInt32 sizeof_uint4 = 4;  //' 4 bytes integer
 	UInt32 sizeof_uint8 = 8;  //' 8 bytes integer
 	UInt32 sizeof_key = sizeof_uint8;
-	
- 
+
+
 	//' Step 1: Determine the bcktab_depth
 	for(bcktab_depth = MAX_DEPTH; bcktab_depth >0; bcktab_depth--) {
 		bcktab_size = 0;
-		
+
 		for(UInt32 i=0; i < size; i++)
-			if(lcptab[i] < bcktab_depth) 
+			if(lcptab[i] < bcktab_depth)
 				bcktab_size++;
-		
-		if(bcktab_depth <= 4) 
+
+		if(bcktab_depth <= 4)
 			sizeof_key = sizeof_uint4;
 
-		if(bcktab_size <= size/(sizeof_key + sizeof_uint4)) 
+		if(bcktab_size <= size/(sizeof_key + sizeof_uint4))
 			break;
 	}
 
 
-	//' Step 2: Allocate memory for bcktab_key and bcktab_val.		
+	//' Step 2: Allocate memory for bcktab_key and bcktab_val.
 	//' Step 3: Precompute coefficients for computing hash values of prefixes later.
-	//' Step 4: Collect the prefixes with lcp <= bcktab_depth and 
+	//' Step 4: Collect the prefixes with lcp <= bcktab_depth and
 	//'           convert them into hash value.
  	if(sizeof_key == sizeof_uint4) {
 		//' (2)
 		bcktab_key4 = new UInt32[bcktab_size];
 		bcktab_val = new UInt32[bcktab_size];
-		assert(bcktab_key4 && bcktab_val);	
+		assert(bcktab_key4 && bcktab_val);
 
 		//' (3)
 		coef4 =  new UInt32[4];
@@ -515,7 +515,7 @@ ESA::ConstructBcktab(const UInt32 &alphabet_size)
 				hash_value4 = 0;
 				for(UInt32 j=0; j < c; j++)
 					hash_value4 += text[suftab[i]+j]*coef4[bcktab_depth-1-j];
-				
+
 				bcktab_key4[k] = hash_value4;
 				bcktab_val[k] = i;
 				k++;
@@ -526,14 +526,14 @@ ESA::ConstructBcktab(const UInt32 &alphabet_size)
 		//' (2)
 		bcktab_key8 = new UInt64[bcktab_size];
 		bcktab_val = new UInt32[bcktab_size];
-		assert(bcktab_key8 && bcktab_val);	
+		assert(bcktab_key8 && bcktab_val);
 
 		//' (3)
 		coef8 =  new UInt64[9];
 		coef8[0] = 1;
 		for(UInt32 i=1; i < 9; i++)
 			coef8[i] = coef8[i-1]*alphabet_size;
-		
+
 		//' (4)
 		for(UInt32 i=0, k=0; i < size; i++) {
 			if(lcptab[i] < bcktab_depth) {
@@ -541,14 +541,14 @@ ESA::ConstructBcktab(const UInt32 &alphabet_size)
 				hash_value8 = 0;
 				for(UInt32 j=0; j < c; j++)
 					hash_value8 += text[suftab[i]+j]*coef8[bcktab_depth-1-j];
-				
+
 				bcktab_key8[k] = hash_value8;
 				bcktab_val[k] = i;
 				k++;
 			}
 		}
 	}
-	
+
 
 	//' check if bcktab in ascending order
 	//	for(UInt32 ii=1; ii<bcktab_size; ii++) {
@@ -557,8 +557,8 @@ ESA::ConstructBcktab(const UInt32 &alphabet_size)
 	//		  std::cout << int(text[bcktab_val[ii]+jj]) << " ";
 	//		std::cout << std::endl;
 	//	}
-	
-		
+
+
 
 	// if(bcktab_key4 && bcktab_key4[ii] <= bcktab_key4[ii-1])
 	//}
@@ -571,10 +571,10 @@ ESA::ConstructBcktab(const UInt32 &alphabet_size)
 
 /**
  *  O(P log N) "Binary" Search version of GetSuflink. Suffix link intervals are not stored
- *    explicitly but bin-searched when needed. 
+ *    explicitly but bin-searched when needed.
  *
  */
-ErrorCode 
+ErrorCode
 ESA::GetSuflink(const UInt32 &i, const UInt32 &j,
 								UInt32 &sl_i, UInt32 &sl_j)
 {
@@ -612,21 +612,21 @@ ESA::GetSuflink(const UInt32 &i, const UInt32 &j,
 		for(UInt32 cnt=0; cnt < offset; cnt++)
 			hash_value4 += coef4[bcktab_depth-1-cnt]*text[suftab[i]+1+cnt];
 
-		
+
 		//' lower bound return the exact position of of target, if found one
 		UInt32 *p = std::lower_bound(bcktab_key4, bcktab_key4+bcktab_size, hash_value4);
 		left = bcktab_val[p - bcktab_key4];
-		
-		
+
+
 		//' this hash value is used to find the right bound of target interval
 		hash_value4 += coef4[bcktab_depth-offset];
 
-		
+
 		//' upper bound return the smallest value > than target.
 		UInt32 *q = std::upper_bound(p, bcktab_key4+bcktab_size, hash_value4);
 		if(q == bcktab_key4+bcktab_size)
 			right = size-1;
-		else 
+		else
 			right = bcktab_val[q - bcktab_key4] - 1;
 	}
 	else if(bcktab_key8) {
@@ -656,21 +656,21 @@ ESA::GetSuflink(const UInt32 &i, const UInt32 &j,
 
 	offset = 0;
 	//' Compute LEFT boundary of suflink interval
-	Compare(left, offset, &text[suftab[i]+1+offset], orig_lcp-1-offset, llcp); 
+	Compare(left, offset, &text[suftab[i]+1+offset], orig_lcp-1-offset, llcp);
  	llcp += offset;
 
 	if(llcp < orig_lcp-1) {
-		Compare(right, offset, &text[suftab[i]+1+offset], orig_lcp-1-offset, rlcp); 
+		Compare(right, offset, &text[suftab[i]+1+offset], orig_lcp-1-offset, rlcp);
     rlcp += offset;
 
 		c = MIN(llcp,rlcp);
 
-	
+
 		while(right-left > 1){
-			mid = (left + right)/2;		
+			mid = (left + right)/2;
 			 Compare(mid, c, &text[suftab[i]+1+c], orig_lcp-1-c, mlcp);
 			mlcp += c;
-			
+
 			//' if target not found yet...
 			if(mlcp < orig_lcp-1) {
 				if(text[suftab[mid]+mlcp] < text[suftab[i]+mlcp+1]) {
@@ -686,12 +686,12 @@ ESA::GetSuflink(const UInt32 &i, const UInt32 &j,
 				//' mlcp == orig_lcp-1
 				assert(mlcp == orig_lcp-1);
 				//' target found, but want to make sure it is the LEFTmost...
-				right = mid;	
+				right = mid;
 				rlcp = mlcp;
 			}
-			c = MIN(llcp, rlcp);	
+			c = MIN(llcp, rlcp);
 		}
-		
+
 		sl_i = right;
 		llcp = rlcp;
 	}
@@ -699,7 +699,7 @@ ESA::GetSuflink(const UInt32 &i, const UInt32 &j,
 		sl_i = left;
 	}
 
-	
+
 
 	//' Compute RIGHT boundary of suflink interval
 	right = tmp_right;
@@ -710,9 +710,9 @@ ESA::GetSuflink(const UInt32 &i, const UInt32 &j,
 	if(rlcp < orig_lcp-1) {
 		c = MIN(llcp,rlcp);
 
-	
+
 		while(right-left > 1){
-			mid = (left + right)/2;		
+			mid = (left + right)/2;
 			Compare(mid, c, &text[suftab[i]+1+c], orig_lcp-1-c, mlcp);
 			mlcp += c;
 
@@ -733,12 +733,12 @@ ESA::GetSuflink(const UInt32 &i, const UInt32 &j,
 				//' mlcp == orig_lcp-1
 				assert(mlcp == orig_lcp-1);
 				//' target found, but want to make sure it is the RIGHTmost...
-				left = mid;	
+				left = mid;
 				llcp = mlcp;
 			}
-			c = MIN(llcp, rlcp);	
+			c = MIN(llcp, rlcp);
 		}
-		
+
 		sl_j = left;
 	}
 	else {
@@ -758,7 +758,7 @@ ESA::GetSuflink(const UInt32 &i, const UInt32 &j,
  *
  *  Pre : 1. Suffix link interval for parent interval has been computed.
  *        2. [child_i..child_j] is not a singleton interval.
- *  
+ *
  *
  *  \param parent_i - (IN) Left bound of parent interval.
  *  \param parent_j - (IN) Right bound of parent interval.
@@ -781,7 +781,7 @@ ESA::FindSuflink(const UInt32 &parent_i, const UInt32 &parent_j,
 	UInt32 lcp_child = 0;
 	UInt32 lcp_parent = 0;
 	UInt32 lcp_sl = 0;
-	
+
 
  	//' Step 1: Get suffix link interval of parent interval and its lcp value.
 	//'      2: Get lcp values of parent and child intervals.
@@ -812,16 +812,16 @@ ESA::FindSuflink(const UInt32 &parent_i, const UInt32 &parent_j,
 
 	//' Traversing down the subtree of [sl_i..sl_j] and looking for
 	//'   the suffix link interval of child interval.
-	
+
 	while (lcp_sl < lcp_child-1) {
-		
+
 		//' The character that we want to look for in suflink interval.
 		ch = text[suftab[child_i]+lcp_sl+1];
-		
+
 		tmp_i = sl_i;
 		tmp_j = sl_j;
 
-		
+
     GetIntervalByChar(tmp_i, tmp_j, ch, lcp_sl, sl_i, sl_j);
 		assert(sl_i<sl_j);  //' There must be a suflink interval for every interval.
 
@@ -829,7 +829,7 @@ ESA::FindSuflink(const UInt32 &parent_i, const UInt32 &parent_j,
 
 		assert(lcp_sl <= lcp_child-1);
 	}
-	
+
 	return NOERROR;
 }
 
@@ -846,50 +846,50 @@ ESA::FindSuflink(const UInt32 &parent_i, const UInt32 &parent_j,
 ErrorCode
 ESA::ConstructSuflink()
 {
- 	//' Breadth-first traversal, need to keep a queue structure to store the 
-	//'   interval-to-explore. Interval-to-explore := (i,j) where [i..j] is an 
+ 	//' Breadth-first traversal, need to keep a queue structure to store the
+	//'   interval-to-explore. Interval-to-explore := (i,j) where [i..j] is an
 	//'   lcp-interval.
-	
+
 	//' Variables
   std::queue< std::pair<UInt32,UInt32> > q;   //' The interval queue
-	std::pair<UInt32,UInt32> interval;    
+	std::pair<UInt32,UInt32> interval;
 
 	//' Step 0: Push root onto queue. And define itself as its suflink.
-	q.push(std::make_pair((unsigned int)0,size-1)); 
+	q.push(std::make_pair((unsigned int)0,size-1));
 
-	UInt32 idx = 0; 
+	UInt32 idx = 0;
 	childtab.l_idx(0,size-1,idx);
 
 	suflink[idx+idx] = 0;          //' left bound of suffix link interval
 	suflink[idx+idx+1] = size-1;   //' right bound of suffix link interval
-	
+
 
 	//' Step 1: Breadth first traversal.
   while (!q.empty()) {
 		//' Step 1.1: Pop interval from queue.
 		interval = q.front(); q.pop();
-		
-		//' Step 1.2: For each non-singleton child-intervals, [p..q], "find" its 
+
+		//' Step 1.2: For each non-singleton child-intervals, [p..q], "find" its
 		//'             suffix link interval and then "push" it onto the interval queue.
-		
+
 		UInt32 i=0,j=0, sl_i=0, sl_j=0, start_idx=interval.first;
 		do {
 			//' Notes: interval.first := left bound of suffix link interval
 			//'        interval.second := right bound of suffix link interval
-			
+
 			assert(interval.first>=0 && interval.second < size);
-			GetIntervalByIndex(interval.first, interval.second, start_idx, i, j); 
-						
+			GetIntervalByIndex(interval.first, interval.second, start_idx, i, j);
+
 			if(j > i) {
 				//' [i..j] is non-singleton interval
 				FindSuflink(interval.first, interval.second, i,j, sl_i, sl_j);
-				
+
 				assert(!(sl_i == i && sl_j == j));
 
 				//' Store suflink of [i..j]
 				UInt32 idx=0;
 				childtab.l_idx(i, j, idx);
-				
+
 				suflink[idx+idx] = sl_i;
 				suflink[idx+idx+1] = sl_j;
 
@@ -899,7 +899,7 @@ ESA::ConstructSuflink()
 
 			start_idx = j+1;  //' prepare to get next child interval
 		}while(start_idx < interval.second);
-			
+
 	}
 
 	return NOERROR;
@@ -907,7 +907,7 @@ ESA::ConstructSuflink()
 
 
 
-/** 
+/**
  *  Get all child-intervals, including singletons.
  *  Store all non-singleton intervals onto #q#, where interval is defined as
  *    (i,j) where i and j are left and right bounds.
@@ -917,7 +917,7 @@ ESA::ConstructSuflink()
  *  \param q  - (OUT) Storage for intervals.
  */
 ErrorCode
-ESA::GetChildIntervals(const UInt32 &lb, const UInt32 &rb, 
+ESA::GetChildIntervals(const UInt32 &lb, const UInt32 &rb,
 											 std::vector<std::pair<UInt32,UInt32> > &q)
 {
 	//' Variables
@@ -951,7 +951,7 @@ ESA::GetChildIntervals(const UInt32 &lb, const UInt32 &rb,
  *    return the child-interval, k-[p..q], of l-[i..j] where p == idx.
  *
  *  Reference: Abo05::algorithm 4.6.4
- * 
+ *
  *  Pre: #start_idx# is a l-index or equal to parent_i.
  *
  *  \param parent_i  - (IN) Left bound of parent interval.
@@ -962,19 +962,19 @@ ESA::GetChildIntervals(const UInt32 &lb, const UInt32 &rb,
  *
  *  Time complexity: O(|alphabet set|)
  */
-ErrorCode 
+ErrorCode
 ESA::GetIntervalByIndex(const UInt32 &parent_i, const UInt32 &parent_j,
 												const UInt32 &start_idx, UInt32 &child_i, UInt32 &child_j)
 {
  	//' Variables
 	UInt32 lcp_child_i = 0;
 	UInt32 lcp_child_j = 0;
-  
+
 	//' Input validation
-	assert( (parent_i < parent_j) && (parent_i >= 0) &&  
-          (parent_j < size) && (start_idx >= parent_i) &&  
+	assert( (parent_i < parent_j) && (parent_i >= 0) &&
+          (parent_j < size) && (start_idx >= parent_i) &&
           (start_idx < parent_j));
-	
+
 	child_i = start_idx;
 
 	//' #start_idx# is not and l-index, i.e. #start_idx == #parent_i#
@@ -988,8 +988,8 @@ ESA::GetIntervalByIndex(const UInt32 &parent_i, const UInt32 &parent_j,
 	//' #start_idx# is a l-index
 	// svnvish:BUGBUG
   child_j = childtab[child_i];
-	lcp_child_i = lcptab[child_i]; 
-	lcp_child_j = lcptab[child_j]; 
+	lcp_child_i = lcptab[child_i];
+	lcp_child_j = lcptab[child_j];
 
 	if(child_i < child_j  &&  lcp_child_i == lcp_child_j)
 		child_j--;
@@ -997,7 +997,7 @@ ESA::GetIntervalByIndex(const UInt32 &parent_i, const UInt32 &parent_j,
 		//' child_i is the left bound of last child interval
 		child_j = parent_j;
 	}
-	
+
 	return NOERROR;
 }
 
@@ -1014,14 +1014,14 @@ ESA::GetIntervalByIndex(const UInt32 &parent_i, const UInt32 &parent_j,
  *  \param parent_i  - (IN) Left bound of parent interval.
  *  \param parent_j  - (IN) Right bound of parent interval.
  *  \param ch        - (IN) Starting character of left bound (suffix) of child interval.
- *  \param depth     - (IN) The position where #ch# is located in #text# 
+ *  \param depth     - (IN) The position where #ch# is located in #text#
  *                            i.e. ch = text[suftab[parent_i]+depth].
  *  \param child_i   - (OUT) Left bound of child interval.
  *  \param child_j   - (OUT) Right bound of child interval.
  *
  *  Time complexity: O(|alphabet set|)
  */
-ErrorCode 
+ErrorCode
 ESA::GetIntervalByChar(const UInt32 &parent_i, const UInt32 &parent_j,
 											 const SYMBOL &ch, const UInt32 &depth,
 											 UInt32 &child_i, UInt32 &child_j)
@@ -1070,7 +1070,7 @@ ESA::GetIntervalByChar(const UInt32 &parent_i, const UInt32 &parent_j,
   idx_next = childtab[idx];
 	lcp_idx = lcptab[idx];
   lcp_idx_next = lcptab[idx_next];
-  
+
 	while(idx < idx_next  &&  lcp_idx == lcp_idx_next  &&  text[suftab[idx]+lcp] < ch) {
 		idx = idx_next;
 		// svnvish: BUGBUG
@@ -1082,7 +1082,7 @@ ESA::GetIntervalByChar(const UInt32 &parent_i, const UInt32 &parent_j,
 
  	if(text[suftab[idx]+lcp] == ch) {
 		child_i = idx;
-		
+
 		if(idx < idx_next && lcp_idx == lcp_idx_next)
 			child_j = idx_next - 1;
 		else
@@ -1117,7 +1117,7 @@ ESA::GetLcp(const UInt32 &i, const UInt32 &j, UInt32 &val)
 
 	//' Variables
 	UInt32 up, down;
-	
+
 	//' 0-[0..size-1]. This is a shortcut!
 	if(i == 0 && j == size) {
 		val = 0;
@@ -1144,13 +1144,13 @@ ESA::GetLcp(const UInt32 &i, const UInt32 &j, UInt32 &val)
  *    length of the substring matched.
  *
  *  \param idx         - (IN) The index of esa.
- *  \param depth       - (IN) The start position of matching mechanism. 
+ *  \param depth       - (IN) The start position of matching mechanism.
  *  \param pattern     - (IN) The pattern string.
  *  \param p_len       - (IN) The length of #pattern#.
  *  \param matched_len - (OUT) The length of matched substring.
  */
 ErrorCode
-ESA::Compare(const UInt32 &idx, const UInt32 &depth, SYMBOL *pattern, 
+ESA::Compare(const UInt32 &idx, const UInt32 &depth, SYMBOL *pattern,
 						 const UInt32 &p_len, UInt32 &matched_len)
 {
 	//' Variables
@@ -1187,29 +1187,29 @@ ESA::Compare(const UInt32 &idx, const UInt32 &depth, SYMBOL *pattern,
  *                              position to start matching.
  *  \param pattern     - (IN) The pattern string to match to esa.
  *  \param p_len       - (IN) The length of #pattern#
- *  \param lb          - (OUT) The left bound of the interval containing 
+ *  \param lb          - (OUT) The left bound of the interval containing
  *                               longest matched suffix.
- *  \param rb          - (OUT) The right bound of the interval containing 
+ *  \param rb          - (OUT) The right bound of the interval containing
  *                               longest matched suffix.
  *  \param matched_len - (OUT) The length of the longest matched suffix.
  *  \param floor_lb    - (OUT) Left bound of floor interval of [lb..rb].
  *  \param floor_rb    - (OUT) Right bound of floor interval of [lb..rb].
  *  \param floor_len   - (OUT) The lcp value of floor interval.
  */
-ErrorCode 
+ErrorCode
 ESA::ExactSuffixMatch(const UInt32 &i, const UInt32 &j, const UInt32 &offset,
-											SYMBOL *pattern, const UInt32 p_len, UInt32 &lb, UInt32 &rb, 
-											UInt32 &matched_len, UInt32 &floor_lb, UInt32 &floor_rb, 
-											UInt32 &floor_len) 
+											SYMBOL *pattern, const UInt32 p_len, UInt32 &lb, UInt32 &rb,
+											UInt32 &matched_len, UInt32 &floor_lb, UInt32 &floor_rb,
+											UInt32 &floor_len)
 {
 	//' Input validation
 	assert(i != j);
 
-	
+
 	//' Variables
 	UInt32 min, lcp;
 	bool queryFound = true;
-	
+
 
 	//' Initial setting.
 	floor_lb = lb = i;
@@ -1221,7 +1221,7 @@ ESA::ExactSuffixMatch(const UInt32 &i, const UInt32 &j, const UInt32 &offset,
 	//' Step 1: Get lcp of floor/starting interval.
 	GetLcp(floor_lb, floor_rb, lcp);
 	floor_len = lcp;
-	
+
 	//' Step 2: Skipping #offset# characters
 	while(lcp < matched_len) {
 		floor_lb = lb;
@@ -1229,17 +1229,17 @@ ESA::ExactSuffixMatch(const UInt32 &i, const UInt32 &j, const UInt32 &offset,
 		floor_len = lcp;
 
     GetIntervalByChar(floor_lb, floor_rb, pattern[lcp], lcp, lb, rb);
-	
+
     //	printf("lb, rb : %i, %i\n", lb, rb);
-	
+
 		assert(lb <= rb);
-				
+
 		if(lb == rb)
 			break;
-		
+
 		GetLcp(lb, rb, lcp);
 	}
-	
+
 	//' Step 3: Continue matching from the point (either an interval or singleton) we stopped.
 	while( (lb<=rb) && queryFound ) {
 		if(lb != rb) {
@@ -1249,8 +1249,8 @@ ESA::ExactSuffixMatch(const UInt32 &i, const UInt32 &j, const UInt32 &offset,
 
 			while(matched_len < min) {
 				queryFound = (text[suftab[lb]+matched_len] == pattern[matched_len]);
- 
-				if(queryFound) 
+
+				if(queryFound)
 					matched_len++;
 				else
 					return NOERROR;
@@ -1260,13 +1260,13 @@ ESA::ExactSuffixMatch(const UInt32 &i, const UInt32 &j, const UInt32 &offset,
 
 			//' Full pattern found!
 			if(matched_len == p_len) return NOERROR;
-			
+
 			floor_lb = lb;
 			floor_rb = rb;
 			floor_len = lcp;
 			GetIntervalByChar(floor_lb, floor_rb,pattern[matched_len],matched_len,lb,rb);
-      			
-		}else { 
+
+		}else {
 			//' lb == rb, i.e. singleton interval.
 			min = (p_len < size-suftab[lb]) ? p_len : size-suftab[lb];
 
@@ -1275,14 +1275,14 @@ ESA::ExactSuffixMatch(const UInt32 &i, const UInt32 &j, const UInt32 &offset,
 
 				if(queryFound)
 					matched_len++;
-				else 
+				else
 					return NOERROR;
 			}
 
 			return NOERROR;
 		}
 	}
-	
+
 	//' If the while loop was broken because of undefined interval,
 	//'   set [i..j] back to previous interval.
 	if(lb > rb) {
